@@ -347,8 +347,8 @@ func (cfg *BuildCfg) shouldRender(p *Page) bool {
 		return true
 	}
 
-	if cfg.whatChanged != nil && p.File != nil && cfg.whatChanged.files[p.File.Filename()] {
-		return true
+	if cfg.whatChanged != nil && p.File != nil {
+		return cfg.whatChanged.files[p.File.Filename()]
 	}
 
 	return false
@@ -676,6 +676,7 @@ type contentChangeMap struct {
 func (m *contentChangeMap) add(filename string, tp bundleDirType) {
 	m.mu.Lock()
 	dir := filepath.Dir(filename) + helpers.FilePathSeparator
+	dir = strings.TrimPrefix(dir, ".")
 	switch tp {
 	case bundleBranch:
 		m.branches = append(m.branches, dir)
@@ -708,10 +709,10 @@ func (m *contentChangeMap) resolveAndRemove(filename string) (string, string, bu
 		dir += helpers.FilePathSeparator
 	}
 
-	fileTp, _ := classifyBundledFile(name)
+	fileTp, isContent := classifyBundledFile(name)
 
 	// This may be a member of a bundle. Start with branch bundles, the most specific.
-	if fileTp != bundleLeaf {
+	if fileTp == bundleBranch || (fileTp == bundleNot && !isContent) {
 		for i, b := range m.branches {
 			if b == dir {
 				m.branches = append(m.branches[:i], m.branches[i+1:]...)
