@@ -15,9 +15,12 @@ package hugolib
 
 import (
 	"bytes"
+	"fmt"
 
 	"errors"
 
+	jww "github.com/spf13/jwalterweatherman"
+
 	"github.com/fsnotify/fsnotify"
 	"github.com/gohugoio/hugo/helpers"
 )
@@ -71,6 +74,11 @@ func (h *HugoSites) Build(config BuildCfg, events ...fsnotify.Event) error {
 		h.Log.FEEDBACK.Println()
 	}
 
+	errorCount := h.Log.LogCountForLevel(jww.LevelError)
+	if errorCount > 0 {
+		return fmt.Errorf("logged %d error(s)", errorCount)
+	}
+
 	return nil
 
 }
@@ -165,8 +173,6 @@ func (h *HugoSites) assemble(config *BuildCfg) error {
 	}
 
 	if config.whatChanged.source {
-		h.assembleGitInfo()
-
 		for _, s := range h.Sites {
 			if err := s.buildSiteMeta(); err != nil {
 				return err
